@@ -39,16 +39,17 @@ void htaccess(const struct userinfostruct *uinfo)
 		return;
 
 	if (snprintf(htname,sizeof(htname),"%s/%s/.htaccess",outdirname,uinfo->filename)>=sizeof(htname)) {
-		debuga(_("File name too long: %s/%s/.htaccess\n"),outdirname,uinfo->filename);
+		debuga(_("Path too long: "));
+		debuga_more("%s/%s/.htaccess\n",outdirname,uinfo->filename);
 		exit(EXIT_FAILURE);
 	}
 	if((fp_auth=fopen(htname,"w"))==NULL) {
-		debuga(_("(auth) Cannot open file: %s - %s\n"),htname,strerror(errno));
+		debugapos("auth",_("Cannot open file \"%s\": %s\n"),htname,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if ((fp_in=fopen(AuthUserTemplateFile,"r"))==NULL) {
-		debuga(_("(auth) Cannot open template file: %s - %s\n"),AuthUserTemplateFile,strerror(errno));
+		debugapos("auth",_("Cannot open file \"%s\": %s\n"),AuthUserTemplateFile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
