@@ -89,7 +89,7 @@ void authfail_report(void)
 		exit(EXIT_FAILURE);
 	}
 	if((fp_in=MY_FOPEN(authfail_in,"r"))==NULL) {
-		debuga(_("(authfail) Cannot open file %s\n"),authfail_in);
+		debugapos("authfail",_("Cannot open file \"%s\": %s\n"),authfail_in,strerror(errno));
 		debuga(_("sort command: %s\n"),csort);
 		exit(EXIT_FAILURE);
 	}
@@ -99,10 +99,11 @@ void authfail_report(void)
 	}
 
 	if((fp_ou=MY_FOPEN(report,"w"))==NULL) {
-		debuga(_("(authfail) Cannot open file %s\n"),report);
+		debugapos("authfail",_("Cannot open file \"%s\": %s\n"),report,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
+	/* TRANSLATORS: This is a column header */
 	write_html_header(fp_ou,(IndexTree == INDEX_TREE_DATE) ? 3 : 1,_("Authentication Failures"),HTML_JS_NONE);
 	fputs("<tr><td class=\"header_c\">",fp_ou);
 	fprintf(fp_ou,_("Period: %s"),period.html);
@@ -114,30 +115,30 @@ void authfail_report(void)
 	fprintf(fp_ou,"<tr><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th></tr>\n",_("USERID"),_("IP/NAME"),_("DATE/TIME"),_("ACCESSED SITE"));
 
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read file %s\n"),authfail_in);
+		debuga(_("Not enough memory to read file \"%s\"\n"),authfail_in);
 		exit(EXIT_FAILURE);
 	}
 
 	while((buf=longline_read(fp_in,line))!=NULL) {
 		getword_start(&gwarea,buf);
 		if (getword(data,sizeof(data),&gwarea,'\t')<0) {
-			debuga(_("There is a broken date in file %s\n"),authfail_in);
+			debuga(_("Invalid date in file \"%s\"\n"),authfail_in);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(hora,sizeof(hora),&gwarea,'\t')<0) {
-			debuga(_("There is a broken time in file %s\n"),authfail_in);
+			debuga(_("Invalid time in file \"%s\"\n"),authfail_in);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(user,sizeof(user),&gwarea,'\t')<0) {
-			debuga(_("There is a broken user ID in file %s\n"),authfail_in);
+			debuga(_("Invalid user in file \"%s\"\n"),authfail_in);
 			exit(EXIT_FAILURE);
 		}
 		if (getword(ip,sizeof(ip),&gwarea,'\t')<0) {
-			debuga(_("There is a broken IP address in file %s\n"),authfail_in);
+			debuga(_("Invalid IP address in file \"%s\"\n"),authfail_in);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_ptr(buf,&url,&gwarea,'\t')<0) {
-			debuga(_("There is a broken url in file %s\n"),authfail_in);
+			debuga(_("Invalid url in file \"%s\"\n"),authfail_in);
 			exit(EXIT_FAILURE);
 		}
 		if (sscanf(data,"%d/%d/%d",&day,&month,&year)!=3) continue;
@@ -146,7 +147,7 @@ void authfail_report(void)
 
 		uinfo=userinfo_find_from_id(user);
 		if (!uinfo) {
-			debuga(_("Unknown user ID %s in file %s\n"),user,authfail_in);
+			debuga(_("Unknown user ID %s in file \"%s\"\n"),user,authfail_in);
 			exit(EXIT_FAILURE);
 		}
 
@@ -202,9 +203,9 @@ void authfail_report(void)
 
 	fputs("</table></div>\n",fp_ou);
 	if (write_html_trailer(fp_ou)<0)
-		debuga(_("Write error in file %s\n"),report);
+		debuga(_("Write error in file \"%s\"\n"),report);
 	if (fclose(fp_ou)==EOF)
-		debuga(_("Failed to close file %s - %s\n"),report,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),report,strerror(errno));
 
 	if (!KeepTempLog && unlink(authfail_in)) {
 		debuga(_("Cannot delete \"%s\": %s\n"),authfail_in,strerror(errno));
