@@ -269,20 +269,19 @@ struct bt *get_disbalanced_node(struct bt *node)
 	struct bt *rdn;
 	if (fabs(node->balanceinfo) > 1)
 		return node;
-	else
-		if (node->left)
-		{
-			rdn = get_disbalanced_node(node->left);
-			if (rdn)
-				return rdn;
-		}
-		if (node->right)
-		{
-			rdn = get_disbalanced_node(node->right);
-			if (rdn)
-				return rdn;
-		}
-		return NULL;
+	if (node->left)
+	{
+		rdn = get_disbalanced_node(node->left);
+		if (rdn)
+			return rdn;
+	}
+	if (node->right)
+	{
+		rdn = get_disbalanced_node(node->right);
+		if (rdn)
+			return rdn;
+	}
+	return NULL;
 }
 
 void init_cache(void)
