@@ -73,12 +73,12 @@ void gen_denied_report(void)
 	sprintf(report,"%s/denied.html",outdirname);
 
 	if((fp_in=MY_FOPEN(denied_in,"r"))==NULL) {
-		debuga(_("(denied) Cannot open log file %s\n"),denied_in);
+		debugapos("denied",_("Cannot open file \"%s\": %s\n"),denied_in,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_ou=MY_FOPEN(report,"w"))==NULL) {
-		debuga(_("(denied) Cannot open log file %s\n"),report);
+		debugapos("denied",_("Cannot open file \"%s\": %s\n"),report,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -93,7 +93,7 @@ void gen_denied_report(void)
 	fprintf(fp_ou,"<tr><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th><th class=\"header_l\">%s</th></tr>\n",_("USERID"),_("IP/NAME"),_("DATE/TIME"),_("ACCESSED SITE"));
 
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read the denied accesses\n"));
+		debuga(_("Not enough memory to read file \"%s\"\n"),denied_in);
 		exit(EXIT_FAILURE);
 	}
 
@@ -101,11 +101,11 @@ void gen_denied_report(void)
 		getword_start(&gwarea,buf);
 		if (getword(data,sizeof(data),&gwarea,'\t')<0 || getword(hora,sizeof(hora),&gwarea,'\t')<0 ||
 		    getword(user,sizeof(user),&gwarea,'\t')<0 || getword(ip,sizeof(ip),&gwarea,'\t')<0) {
-			debuga(_("There is a broken record or garbage in file %s\n"),denied_in);
+			debuga(_("Invalid record in file \"%s\"\n"),denied_in);
 			exit(EXIT_FAILURE);
 		}
 		if (getword_ptr(buf,&url,&gwarea,'\t')<0) {
-			debuga(_("There is a broken url in file %s\n"),denied_in);
+			debuga(_("Invalid url in file \"%s\"\n"),denied_in);
 			exit(EXIT_FAILURE);
 		}
 		if (sscanf(data,"%d/%d/%d",&day,&month,&year)!=3) continue;
@@ -114,7 +114,7 @@ void gen_denied_report(void)
 
 		uinfo=userinfo_find_from_id(user);
 		if (!uinfo) {
-			debuga(_("Unknown user ID %s in file %s\n"),user,denied_in);
+			debuga(_("Unknown user ID %s in file \"%s\"\n"),user,denied_in);
 			exit(EXIT_FAILURE);
 		}
 
@@ -173,9 +173,9 @@ void gen_denied_report(void)
 
 	fputs("</table></div>\n",fp_ou);
 	if (write_html_trailer(fp_ou)<0)
-		debuga(_("Write error in file %s\n"),report);
-	if (fclose(fp_ou)<0)
-		debuga(_("Failed to close file %s - %s\n"),report,strerror(errno));
+		debuga(_("Write error in file \"%s\"\n"),report);
+	if (fclose(fp_ou)==EOF)
+		debuga(_("Failed to close file \"%s\": %s\n"),report,strerror(errno));
 
 	if (!KeepTempLog && unlink(denied_in)==-1)
 		debuga(_("Cannot delete \"%s\": %s\n"),denied_in,strerror(errno));
