@@ -193,14 +193,14 @@ void gethexclude(const char *hexfile, int debug)
 	const char *next;
 
 	if(access(hexfile, R_OK) != 0) {
-		debuga(_("Cannot open exclude_hosts file: %s - %s\n"),hexfile,strerror(errno));
+		debuga(_("Cannot open file \"%s\": %s\n"),hexfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	if(debug)
 		debuga(_("Loading exclude host file from: %s\n"),hexfile);
 
 	if ((fp_ex = fopen(hexfile, "r")) == NULL) {
-		debuga(_("(gethexclude) Cannot open file %s - %s\n"),hexfile,strerror(errno));
+		debugapos("gethexclude",_("Cannot open file \"%s\": %s\n"),hexfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -314,27 +314,27 @@ void getuexclude(const char *uexfile, int debug)
 		debuga(_("Loading exclude file from: %s\n"),uexfile);
 
 	if ((fp_ex = fopen(uexfile, "r")) == NULL) {
-		debuga(_("(gethexclude) Cannot open file %s - %s\n"),uexfile,strerror(errno));
+		debugapos("gethexclude",_("Cannot open file \"%s\": %s\n"),uexfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if (fseek(fp_ex, 0, SEEK_END)==-1) {
-		debuga(_("Failed to move till the end of the excluded users file %s: %s\n"),uexfile,strerror(errno));
+		debuga(_("Failed to move till the end of file \"%s\": %s\n"),uexfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	nreg = ftell(fp_ex);
 	if (nreg<0) {
-		debuga(_("Cannot get the size of file %s\n"),uexfile);
+		debuga(_("Cannot get the size of file \"%s\": %s\n"),uexfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	nreg += 11;
 	if (fseek(fp_ex, 0, SEEK_SET)==-1) {
-		debuga(_("Failed to rewind the excluded users file %s: %s\n"),uexfile,strerror(errno));
+		debuga(_("Failed to rewind file \"%s\": %s\n"),uexfile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if((excludeuser=(char *) malloc(nreg))==NULL){
-		debuga(_("malloc error (%ld bytes required)\n"),nreg);
+		debuga(_("malloc failed to allocate %ld bytes\n"),nreg);
 		exit(EXIT_FAILURE);
 	}
 
