@@ -468,7 +468,7 @@ static void parmtest(char *buf)
 	if (is_param("date_format",buf)) {
 		getword_start(&gwarea,buf);
 		if (getword_multisep(wbuf,sizeof(wbuf),&gwarea,' ')<0) {
-			debuga(_("Maybe you have a broken record or garbage in \"date_format\" parameter\n"));
+			debuga(_("Invalid value in the \"date_format\" parameter\n"));
 			exit(EXIT_FAILURE);
 		}
 		strncpy(DateFormat,gwarea.current,1);
@@ -784,7 +784,7 @@ void getconf(void)
 		debuga(_("Loading configuration from %s\n"),ConfigFile);
 
 	if ((fp_in = fopen(ConfigFile, "r")) == NULL) {
-		debuga(_("(getconf) Cannot open file %s\n"),ConfigFile);
+		debugapos("getconf",_("Cannot open file \"%s\": %s\n"),ConfigFile,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
