@@ -154,7 +154,10 @@ static void Sarg_gdImageStringFT (struct GraphDataStruct *gdata, int fg, char *f
 		str = string;
 		sstr = sstring;
 		if (iconv (localtoutf, (ICONV_CONST char **)&str, &slen, &sstr, &sslen)==-1) {
-			debuga(_("(grepday) iconv failed to convert string \"%s\" from %s to UTF-8 - %s\n"),string,CharSet,strerror(errno));
+			/* TRANSLATORS: First %s is the string that failed to convert. Second %s is the input
+			 * character encoding. Last %s is the reason for the failure.
+			 */
+			debugapos("grepday",_("iconv failed to convert string \"%s\" from %s to UTF-8: %s\n"),string,CharSet,strerror(errno));
 			sstring=(char *)string; //show something sensible on the graph
 		}
 	} else {
@@ -610,11 +613,13 @@ static void greport_plot(const struct userinfostruct *uinfo,struct PlotStruct *p
 	}
 
 	if (snprintf(graph,sizeof(graph),"%s/%s/%s",outdirname,uinfo->filename,pdata->pngfile)>=sizeof(graph)) {
-		debuga(_("user name too long for %s/%s/%s\n"),outdirname,uinfo->filename,pdata->pngfile);
+		/* TRANSLATORS: The message is followed by the path that is too long. */
+		debuga(_("User name too long to manufacture file name "));
+		debuga_more("%s/%s/%s\n",outdirname,uinfo->filename,pdata->pngfile);
 		exit(EXIT_FAILURE);
 	}
 	if((pngout=fopen(graph,"wb"))==NULL) {
-		debuga(_("(grepday) Cannot open log file %s\n"),graph);
+		debugapos("grepday",_("Cannot open file \"%s\": %s\n"),graph,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	gdImagePng(gdata.im, pngout);
@@ -630,25 +635,33 @@ void greport_prepare(void)
 {
 #ifdef HAVE_GD
 	if (!Graphs) {
-		if (debugz)
-			debugaz(_("Graphs disabled as requested in %s\n"),ConfigFile);
+		if (debugz) {
+			/* TRANSLATORS: %s is the name of the configuration file providing
+			 * the graph option.
+			 */
+			debugaz(_("Graphs disabled as requested in \"%s\"\n"),ConfigFile);
+		}
 		return;
 	}
 	if (GraphFont[0]=='\0') {
-		if (debugz)
-			debugaz(_("Graphs disabled as no font names were provided in %s\n"),ConfigFile);
+		if (debugz) {
+			/* TRANSLATORS: %s is the name of the configuration file providing
+			 * the graph option.
+			 */
+			debugaz(_("Graphs disabled as no font names were provided in \"%s\"\n"),ConfigFile);
+		}
 		return;
 	}
 
 	if(access(GraphFont, R_OK) != 0) {
-		debuga(_("(grepday) Fontname %s not found\n"),GraphFont);
+		debugapos("grepday",_("Fontname \"%s\" not found\n"),GraphFont);
 		exit(EXIT_FAILURE);
 	}
 
 #ifdef USE_ICONV
 	localtoutf = iconv_open ("UTF-8", CharSet);
 	if (localtoutf==(iconv_t)-1) {
-		debuga(_("(grepday) iconv cannot convert from %s to UTF-8 - %s\n"),CharSet,strerror(errno));
+		debugapos("grepday",_("iconv cannot convert from %s to UTF-8: %s\n"),CharSet,strerror(errno));
 	}
 #endif
 
@@ -671,7 +684,8 @@ void greport_day(const struct userinfostruct *uinfo)
 	struct PlotStruct pdata;
 
 	if (snprintf(wdirname,sizeof(wdirname),"%s/%s.day",tmp,uinfo->filename)>=sizeof(wdirname)) {
-		debuga(_("user name too long for %s/%s.day\n"),tmp,uinfo->filename);
+		debuga(_("User name too long to manufacture file name "));
+		debuga_more("%s/%s.day\n",tmp,uinfo->filename);
 		exit(EXIT_FAILURE);
 	}
 	if(access(wdirname, R_OK) != 0) {
@@ -684,7 +698,7 @@ void greport_day(const struct userinfostruct *uinfo)
 	}
 
 	if((fp_in=fopen(wdirname,"r"))==NULL) {
-		debuga(_("(grepday) Cannot open log file %s\n"),wdirname);
+		debugapos("grepday",_("Cannot open file \"%s\": %s\n"),wdirname,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -694,25 +708,25 @@ void greport_day(const struct userinfostruct *uinfo)
 		fixendofline(buf);
 		getword_start(&gwarea,buf);
 		if (getword_atoll(&llday,&gwarea,'/')<0) {
-			debuga(_("Invalid date in file %s\n"),wdirname);
+			debuga(_("Invalid date in file \"%s\"\n"),wdirname);
 			exit(EXIT_FAILURE);
 		}
 		day=(int)llday;
 		if (day<1 || day>31) continue;
 		if (getword_skip(20,&gwarea,'\t')<0 || getword_skip(20,&gwarea,'\t')<0) {
-			debuga(_("Invalid entry in file %s\n"),wdirname);
+			debuga(_("Invalid entry in file \"%s\"\n"),wdirname);
 			exit(EXIT_FAILURE);
 		}
 		if ((datetimeby & DATETIME_BYTE)!=0) {
 			if (getword_atoll(&bytes,&gwarea,'\t')<0) {
-				debuga(_("Invalid number of bytes in file %s\n"),wdirname);
+				debuga(_("Invalid number of bytes in file \"%s\"\n"),wdirname);
 				exit(EXIT_FAILURE);
 			}
 			bytespoints[day-1]+=bytes;
 		}
 		if ((datetimeby & DATETIME_ELAP)!=0) {
 			if (getword_atoll(&elap,&gwarea,'\0')<0) {
-				debuga(_("Invalid elapsed time in file %s\n"),wdirname);
+				debuga(_("Invalid elapsed time in file \"%s\"\n"),wdirname);
 				exit(EXIT_FAILURE);
 			}
 			elappoints[day-1]+=elap;
@@ -725,11 +739,12 @@ void greport_day(const struct userinfostruct *uinfo)
 	}
 
 	if (snprintf(wdirname,sizeof(wdirname),"%s/%s/graph.html",outdirname,uinfo->filename)>=sizeof(wdirname)) {
-		debuga(_("user name too long for %s/%s/%s\n"),outdirname,uinfo->filename,"graph.html");
+		debuga(_("User name too long to manufacture file name "));
+		debuga_more("%s/%s/%s\n",outdirname,uinfo->filename,"graph.html");
 		exit(EXIT_FAILURE);
 	}
 	if ((fp_ou=fopen(wdirname,"wt"))==NULL) {
-		debuga(_("(grepday) Cannot open output file %s\n"),wdirname);
+		debugapos("grepday",_("Cannot open file \"%s\": %s\n"),wdirname,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	write_html_head(fp_ou,(IndexTree == INDEX_TREE_DATE) ? 4 : 2,_("Graph report"),HTML_JS_NONE);
@@ -764,9 +779,9 @@ void greport_day(const struct userinfostruct *uinfo)
 	fputs("</table>\n",fp_ou);
 
 	if (write_html_trailer(fp_ou)<0)
-		debuga(_("Write error in file %s\n"),wdirname);
+		debuga(_("Write error in file \"%s\"\n"),wdirname);
 	if (fclose(fp_ou)==EOF)
-		debuga(_("Failed to close file %s - %s\n"),wdirname,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),wdirname,strerror(errno));
 #endif //HAVE_GD
 
 	return;
