@@ -265,6 +265,7 @@ Sarg will complain that there are too many days in the files if this limit is ov
 #define TOPSITE_SORT_BYTES   0x0002UL
 #define TOPSITE_SORT_CONNECT 0x0004UL
 #define TOPSITE_SORT_TIME    0x0008UL
+#define TOPSITE_SORT_USER    0x0010UL
 
 #define USER_SORT_REVERSE SORT_REVERSE
 #define USER_SORT_BYTES   0x0002UL
@@ -475,6 +476,8 @@ int  nrepday;
 int  ndownload;
 int  ntopuser;
 bool  squid24;
+//! \c True to keep the temporary files for inspection.
+bool KeepTempLog;
 
 long long int nocost;
 float cost;
