@@ -35,7 +35,7 @@ void index_only(const char *dirname,int debug)
 	char remove[MAXLEN];
 
 	if ((dirp = opendir(dirname)) == NULL) {
-		debuga(_("Failed to open directory %s - %s\n"),dirname,strerror(errno));
+		debuga(_("Cannot open directory \"%s\": %s\n"),dirname,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	while ( (direntp = readdir( dirp )) != NULL ){
