@@ -404,7 +404,7 @@ int main(int argc,char *argv[])
 				break;
 			case 'd':
 				safe_strcpy(date,optarg,sizeof(date));
-				date_from(date, &dfrom, &duntil);
+				date_from(date, sizeof(date), &dfrom, &duntil);
 				break;
 			case 'e':
 				safe_strcpy(email,optarg,sizeof(email));
@@ -443,7 +443,7 @@ int main(int argc,char *argv[])
 					exit(EXIT_FAILURE);
 				}
 				if (strlen(optarg)>=MAX_REDIRECTOR_FILELEN) {
-					debuga(_("Log file name too long passed on command line with opton %s: %s\n"),"-L",optarg);
+					debuga(_("Log file name too long passed on command line with option %s: %s\n"),"-L",optarg);
 					exit(EXIT_FAILURE);
 				}
 				strcpy(RedirectorLogs[NRedirectorLogs],optarg);
@@ -1478,8 +1478,10 @@ int main(int argc,char *argv[])
 				}
 			}
 #ifdef ENABLE_DOUBLE_CHECK_DATA
-			ufile->user->nbytes+=nbytes;
-			ufile->user->elap+=elap_time;
+			if (strcmp(code,"TCP_DENIED/407")!=0) {
+				ufile->user->nbytes+=nbytes;
+				ufile->user->elap+=elap_time;
+			}
 #endif
 
 			if (ufile->file==NULL) {
