@@ -90,14 +90,14 @@ void gerarel(void)
 	}
 
 	if(debugz){
-		debugaz(_("outdirname=%s\n"),outdirname);
+		debugaz(_("Report output directory name=%s\n"),outdirname);
 	}
 
 	if(UserAgentLog[0] != '\0' && email[0] == '\0') useragent();
 
 	snprintf(wdirname,sizeof(wdirname),"%s/sarg-general",outdirname);
 	if((fp_gen=MY_FOPEN(wdirname,"w"))==NULL){
-		debuga(_("(report) Cannot open file %s\n"),wdirname);
+		debugapos("report",_("Cannot open file \"%s\": %s\n"),wdirname,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -117,11 +117,12 @@ void gerarel(void)
 	while ((uinfo = userinfo_advancescan(uscan)) != NULL ) {
 		sort_users_log(tmp,debug,uinfo);
 		if (snprintf(tmp3,sizeof(tmp3),"%s/%s.user_log",tmp,uinfo->filename)>=sizeof(tmp3)) {
-			debuga(_("(report) directory entry too long: %s/%s.user_log\n"),tmp,uinfo->filename);
+			debugapos("report",_("Path too long: "));
+			debuga_more("%s/%s.user_log\n",tmp,uinfo->filename);
 			exit(EXIT_FAILURE);
 		}
 		if((fp_in=MY_FOPEN(tmp3,"r"))==NULL){
-			debuga(_("(report) Cannot open file %s\n"),tmp);
+			debugapos("report",_("Cannot open file \"%s\": %s\n"),tmp,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 		user=uinfo->filename;
@@ -153,7 +154,7 @@ void gerarel(void)
 		oucache=0;
 
 		if ((line=longline_create())==NULL) {
-			debuga(_("Not enough memory to read the downloaded files\n"));
+			debuga(_("Not enough memory to read file \"%s\"\n"),tmp3);
 			exit(EXIT_FAILURE);
 		}
 
@@ -163,16 +164,16 @@ void gerarel(void)
 			    getword(accip,sizeof(accip),&gwarea,'\t')<0 ||
 			    getword_ptr(buf,&accurl,&gwarea,'\t')<0 || getword_atoll(&accbytes,&gwarea,'\t')<0 ||
 			    getword(acccode,sizeof(acccode),&gwarea,'\t')<0) {
-				debuga(_("There is a broken record or garbage in file %s\n"),tmp3);
+				debuga(_("Invalid record in file \"%s\"\n"),tmp3);
 				exit(EXIT_FAILURE);
 			}
 			if(strncmp(acccode,"TCP_DENIED/407",14) == 0) continue;
 			if (getword_atoll(&accelap,&gwarea,'\t')<0) {
-				debuga(_("There is a broken elapsed time in file %s\n"),tmp3);
+				debuga(_("Invalid elapsed time in file \"%s\"\n"),tmp3);
 				exit(EXIT_FAILURE);
 			}
 			if (getword_skip(20000,&gwarea,'"')<0 || getword(accsmart,sizeof(accsmart),&gwarea,'"')<0) {
-				debuga(_("There is a broken smart info in file %s\n"),tmp3);
+				debuga(_("Invalid smart info in file \"%s\"\n"),tmp3);
 				exit(EXIT_FAILURE);
 			}
 
@@ -242,7 +243,7 @@ void gerarel(void)
 					url_to_file(accurl,siteind,sizeof(siteind));
 					snprintf(arqtt,sizeof(arqtt),"%s/%s/tt%s-%s.html",outdirname,uinfo->filename,uinfo->filename,siteind);
 					if ((fp_tt = fopen(arqtt, "w")) == 0) {
-						debuga(_("(report) Cannot open file %s\n"),arqtt);
+						debugapos("report",_("Cannot open file \"%s\": %s\n"),arqtt,strerror(errno));
 						exit(EXIT_FAILURE);
 					}
 					ttopen=1;
@@ -328,7 +329,7 @@ void gerarel(void)
 		}
 		if (fp_tmp) {
 			if (fclose(fp_tmp)==EOF)
-				debuga(_("Failed to close temporary file for user %s - %s\n"),uinfo->filename,strerror(errno));
+				debuga(_("Failed to close file \"%s\": %s\n"),uinfo->filename,strerror(errno));
 			fp_tmp=NULL;
 		}
 		if (!KeepTempLog && unlink(tmp3)) {
@@ -417,14 +418,15 @@ static FILE *maketmp(const char *user, const char *dirname, int debug)
 	if((ReportType & REPORT_TYPE_USERS_SITES) == 0) return(NULL);
 	if((ReportType & REPORT_TYPE_TOPUSERS) == 0) return(NULL);
 
-	if(debug) debuga(_("Making file: %s/%s\n"),tmp,user);
+	if(debug) debuga(_("Making file %s/%s\n"),tmp,user);
 	if (snprintf(wdirname,sizeof(wdirname),"%s/%s.utmp",tmp,user)>=sizeof(wdirname)) {
-		debuga(_("Temporary file name too long: %s/%s.utmp\n"),tmp,user);
+		debuga(_("Path too long: "));
+		debuga_more("%s/%s.utmp\n",tmp,user);
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_ou=fopen(wdirname,"w"))==NULL){
-		debuga(_("(report) Cannot open file %s\n"),wdirname);
+		debugapos("report",_("Cannot open file \"%s\": %s\n"),wdirname,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -460,12 +462,13 @@ static void gravaporuser(const struct userinfostruct *uinfo, const char *dirname
 	if((ReportType & REPORT_TYPE_USERS_SITES) == 0) return;
 
 	if (snprintf(wdirname,sizeof(wdirname),"%s/%s.ip",tmp,uinfo->filename)>=sizeof(wdirname)) {
-		debuga(_("Path too long %s/%s.ip\n"),tmp,uinfo->filename);
+		debuga(_("Path too long: "));
+		debuga_more("%s/%s.ip\n",tmp,uinfo->filename);
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_ou=MY_FOPEN(wdirname,"a"))==NULL){
-		debuga(_("(report) Cannot open file %s\n"),wdirname);
+		debugapos("report",_("Cannot open file \"%s\": %s\n"),wdirname,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -488,7 +491,7 @@ static void gravager(FILE *fp_gen,const char *filename, const struct userinfostr
 	to print a long long int unless it is exactly 64-bits long.
 	*/
 	if (fprintf(fp_gen,"%s\t%"PRIu64"\t%"PRIu64"\t%s\t%s\t%s\t%s\t%"PRIu64"\t%"PRIu64"\t%"PRIu64"\n",uinfo->id,(uint64_t)nacc,(uint64_t)nbytes,url,ip,hora,dia,(uint64_t)nelap,(uint64_t)incache,(uint64_t)oucache)<0) {
-		debuga(_("Failed to write a line in %s\n"),filename);
+		debuga(_("Failed to write a line in \"%s\"\n"),filename);
 		exit(EXIT_FAILURE);
 	}
 
@@ -510,7 +513,7 @@ void totalger(FILE *fp_gen,const char *filename)
 	to print a long long int unless it is exactly 64-bits long.
 	*/
 	if (fprintf(fp_gen,"TOTAL\t%"PRIu64"\t%"PRIu64"\t%"PRIu64"\t%"PRIu64"\t%"PRIu64"\n",(uint64_t)globstat.nacc,(uint64_t)globstat.nbytes,(uint64_t)globstat.elap,(uint64_t)globstat.incache,(uint64_t)globstat.oucache)<0) {
-		debuga(_("Failed to write the total line in %s\n"),filename);
+		debuga(_("Failed to write the total line in \"%s\"\n"),filename);
 		exit(EXIT_FAILURE);
 	}
 }
@@ -536,7 +539,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\t') {
-			debuga(_("Invalid total number of accesses in %s\n"),filename);
+			debuga(_("Invalid total number of accesses in file \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		buffer++;
@@ -553,7 +556,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\t') {
-			debuga(_("Invalid total size in %s\n"),filename);
+			debuga(_("Invalid total size in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		buffer++;
@@ -570,7 +573,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\t') {
-			debuga(_("Invalid total elapsed time in %s\n"),filename);
+			debuga(_("Invalid total elapsed time in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		buffer++;
@@ -587,7 +590,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\t') {
-			debuga(_("Invalid total cache hit in %s\n"),filename);
+			debuga(_("Invalid total cache hit in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		buffer++;
@@ -604,7 +607,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\0') {
-			debuga(_("Invalid total cache miss in %s\n"),filename);
+			debuga(_("Invalid total cache miss in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		item->oucache=number*sign;
@@ -614,7 +617,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		item->user=buffer;
 		for (i=0 ; i<MAX_USER_LEN-1 && (unsigned char)*buffer>=' ' ; i++) buffer++;
 		if (*buffer!='\t') {
-			debuga(_("User name too long or invalid in %s\n"),filename);
+			debuga(_("User name too long or invalid in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		*buffer++='\0';
@@ -630,7 +633,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\t') {
-			debuga(_("Invalid number of accesses in %s\n"),filename);
+			debuga(_("Invalid number of accesses in file \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		buffer++;
@@ -647,7 +650,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\t') {
-			debuga(_("Invalid number of bytes in %s\n"),filename);
+			debuga(_("Invalid number of bytes in file \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		buffer++;
@@ -656,7 +659,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		item->url=buffer;
 		while ((unsigned char)*buffer>=' ') buffer++;
 		if (*buffer!='\t') {
-			debuga(_("URL too long or invalid in %s\n"),filename);
+			debuga(_("URL too long or invalid in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		*buffer++='\0';
@@ -664,7 +667,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		item->ip=buffer;
 		for (i=0 ; i<MAX_IP_LEN-1 && (unsigned char)*buffer>=' ' ; i++) buffer++;
 		if (*buffer!='\t') {
-			debuga(_("IP address too long or invalid in %s\n"),filename);
+			debuga(_("IP address too long or invalid in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		*buffer++='\0';
@@ -672,7 +675,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		item->time=buffer;
 		for (i=0 ; i<MAX_DATETIME_LEN-1 && (unsigned char)*buffer>=' ' ; i++) buffer++;
 		if (*buffer!='\t') {
-			debuga(_("Time too long or invalid in %s\n"),filename);
+			debuga(_("Time too long or invalid in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		*buffer++='\0';
@@ -680,7 +683,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		item->date=buffer;
 		for (i=0 ; i<MAX_DATETIME_LEN-1 && (unsigned char)*buffer>=' ' ; i++) buffer++;
 		if (*buffer!='\t') {
-			debuga(_("Date too long or invalid in %s\n"),filename);
+			debuga(_("Date too long or invalid in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		*buffer++='\0';
@@ -696,7 +699,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\t') {
-			debuga(_("Invalid elapsed time in %s\n"),filename);
+			debuga(_("Invalid elapsed time in file \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		buffer++;
@@ -713,7 +716,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\t') {
-			debuga(_("Invalid cache hit size in %s\n"),filename);
+			debuga(_("Invalid cache hit size in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		buffer++;
@@ -730,7 +733,7 @@ int ger_read(char *buffer,struct generalitemstruct *item,const char *filename)
 		while (isdigit(*buffer))
 			number=(number * 10) + (*buffer++)-'0';
 		if (*buffer!='\0') {
-			debuga(_("Invalid cache miss size in %s\n"),filename);
+			debuga(_("Invalid cache miss size in \"%s\"\n"),filename);
 			exit(EXIT_FAILURE);
 		}
 		item->oucache=number*sign;
@@ -744,12 +747,13 @@ static void grava_SmartFilter(const char *dirname, const char *user, const char
 	char wdirname[MAXLEN];
 
 	if (snprintf(wdirname,sizeof(wdirname),"%s/smartfilter.int_unsort",dirname)>=sizeof(wdirname)) {
-		debuga(_("File name too long for %s/smartfilter.int_unsort\n"),dirname);
+		debuga(_("Path too long: "));
+		debuga_more("%s/smartfilter.int_unsort\n",dirname);
 		exit(EXIT_FAILURE);
 	}
 
 	if((fp_ou=MY_FOPEN(wdirname,"a"))==NULL){
-		debuga(_("(report) Cannot open file %s\n"),wdirname);
+		debugapos("report",_("Cannot open file \"%s\": %s\n"),wdirname,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
