@@ -33,6 +33,7 @@ void smartfilter_report(void)
 
 	char buf[MAXLEN];
 	char url[MAXLEN];
+	char pgmurl[250];
 	char csort[255];
 	char smart_in[MAXLEN];
 	char smart_ou[MAXLEN];
@@ -54,19 +55,23 @@ void smartfilter_report(void)
 	ouser[0]='\0';
 
 	if (snprintf(smart_in,sizeof(smart_in),"%s/smartfilter.int_unsort",tmp)>=sizeof(smart_in)) {
-		debuga(_("File name too long: %s/smartfilter.int_unsort\n"),tmp);
+		debuga(_("Path too long: "));
+		debuga_more("%s/smartfilter.int_unsort\n",tmp);
 		exit(EXIT_FAILURE);
 	}
 	if (snprintf(sites,sizeof(sites),"%s/sarg-sites",outdirname)>=sizeof(sites)) {
-		debuga(_("File name too long: %s/sarg-sites\n"),outdirname);
+		debuga(_("Path too long: "));
+		debuga_more("%s/sarg-sites\n",outdirname);
 		exit(EXIT_FAILURE);
 	}
 	if (snprintf(smart_ou,sizeof(smart_ou),"%s/smartfilter.int_log",tmp)>=sizeof(smart_ou)) {
-		debuga(_("File name too long: %s/smartfilter.int_log\n"),tmp);
+		debuga(_("Path too long: "));
+		debuga_more("%s/smartfilter.int_log\n",tmp);
 		exit(EXIT_FAILURE);
 	}
 	if (snprintf(report,sizeof(report),"%s/smartfilter.html",outdirname)>=sizeof(report)) {
-		debuga(_("File name too long: %s/smartfilter.html\n"),outdirname);
+		debuga(_("Path too long: "));
+		debuga_more("%s/smartfilter.html\n",outdirname);
 		exit(EXIT_FAILURE);
 	}
 
@@ -81,7 +86,7 @@ void smartfilter_report(void)
 		exit(EXIT_FAILURE);
 	}
 	if((fp_in=fopen(smart_ou,"r"))==NULL) {
-		debuga(_("(smartfilter) Cannot open log file %s\n"),smart_ou);
+		debugapos("smartfilter",_("Cannot open file \"%s\": %s\n"),smart_ou,strerror(errno));
 		debuga(_("sort command: %s\n"),csort);
 		exit(EXIT_FAILURE);
 	}
@@ -91,7 +96,7 @@ void smartfilter_report(void)
 	}
 
 	if((fp_ou=fopen(report,"w"))==NULL) {
-		debuga(_("(smartfilter) Cannot open log file %s\n"),report);
+		debugapos("smartfilter",_("Cannot open file \"%s\": %s\n"),report,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
@@ -114,19 +119,20 @@ void smartfilter_report(void)
 	fputs("<tr><td></td></tr>\n",fp_ou);
 	fputs("<tr><td></td></tr>\n",fp_ou);
 	fprintf(fp_ou,"<tr><th bgcolor=%s><font size=\"%s\">%s</font></th><th bgcolor=\"%s\"><font size=\"%s\">%s</font></th><th bgcolor=\"%s\"><font size=\"%s\">%s</font></th><th bgcolor=\"%s\"><font size=\"%s\">%s</font></th><th bgcolor=\"%s\"><font size=\"%s\">%s</font></th></tr>\n",HeaderBgColor,FontSize,_("USERID"),HeaderBgColor,FontSize,_("IP/NAME"),HeaderBgColor,FontSize,_("DATE/TIME"),HeaderBgColor,FontSize,_("ACCESSED SITE"),HeaderBgColor,FontSize,_("SMARTFILTER"));
+	snprintf(pgmurl,sizeof(pgmurl),"<a href=\"%s\">%s-%s</a>",URL,PGM,VERSION);
 
 	while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
 		getword_start(&gwarea,buf);
 		if (getword(user,sizeof(user),&gwarea,'\t')<0 || getword(data,sizeof(data),&gwarea,'\t')<0 ||
 		    getword(hora,sizeof(hora),&gwarea,'\t')<0 || getword(ip,sizeof(ip),&gwarea,'\t')<0 ||
 		    getword(url,sizeof(url),&gwarea,'\t')<0 || getword(smartcat,sizeof(smartcat),&gwarea,'\n')<0) {
-			debuga(_("There is a broken record or garbage in file %s\n"),smart_ou);
+			debuga(_("Invalid record in file \"%s\"\n"),smart_ou);
 			exit(EXIT_FAILURE);
 		}
 
 		uinfo=userinfo_find_from_id(user);
 		if (!uinfo) {
-			debuga(_("Unknown user ID %s in file %s\n"),user,smart_ou);
+			debuga(_("Unknown user ID %s in file \"%s\"\n"),user,smart_ou);
 			exit(EXIT_FAILURE);
 		}
 		if(strcmp(ouser,user) != 0) {
@@ -137,13 +143,18 @@ void smartfilter_report(void)
 				fputs("</table>\n",fp_user);
 				if(ShowSargInfo) {
 					zdate(ftime, sizeof(ftime), DateFormat);
-					fprintf(fp_user,"<br><br><div align=\"center\"><font size=\"-2\">%s <a href=\"%s\">%s-%s</a> %s %s</font></div>\n",_("Generated by"),URL,PGM,VERSION,_("on"),ftime);
+					fputs("<br><br><div align=\"center\"><font size=\"-2\">",fp_user);
+					/* TRANSLATORS: The first %s is an html <a> tag with a link to the sarg
+					 * website. The second %s is the report generation time.
+					 */
+					fprintf(fp_user,_("Generated by %s on %s"),pgmurl,ftime);
+					fputs("</font></div>\n",fp_user);
 				}
 				fputs("</body>\n</html>\n",fp_user);
 				fclose(fp_user);
 			}
 			if ((fp_user = fopen(smartuser, "a")) == 0) {
-				debuga(_("(smartfilter) Cannot open file %s\n"),smartuser);
+				debugapos("smartfilter",_("Cannot open file \"%s\": %s\n"),smartuser,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 			fuser=1;
@@ -191,7 +202,9 @@ void smartfilter_report(void)
 
 	if(ShowSargInfo) {
 		zdate(ftime, sizeof(ftime), DateFormat);
-		fprintf(fp_ou,"<br><br><div align=\"center\"><font size=\"-2\">%s <a href=\"%s\">%s-%s</a> %s %s</font></div>\n",_("Generated by"),URL,PGM,VERSION,_("on"),ftime);
+		fputs("<br><br><div align=\"center\"><font size=\"-2\">",fp_ou);
+		fprintf(fp_ou,_("Generated by %s on %s"),pgmurl,ftime);
+		fputs("</font></div>\n",fp_ou);
 	}
 
 	fputs("</body>\n</html>\n",fp_user);
@@ -201,7 +214,9 @@ void smartfilter_report(void)
 		fputs("</table>\n",fp_user);
 		if(ShowSargInfo) {
 			zdate(ftime, sizeof(ftime), DateFormat);
-			fprintf(fp_user,"<br><br><div align=\"center\"><font size=\"-2\">%s <a href=\"%s\">%s-%s</a> %s %s</font></div>\n",_("Generated by"),URL,PGM,VERSION,_("on"),ftime);
+			fputs("<br><br><div align=\"center\"><font size=\"-2\">",fp_user);
+			fprintf(fp_user,_("Generated by %s on %s"),pgmurl,ftime);
+			fputs("</font></div>\n",fp_user);
 		}
 		fputs("</body>\n</html>\n",fp_user);
 		fclose(fp_user);
