@@ -63,20 +63,23 @@ void tmpsort(const struct userinfostruct *uinfo)
 		order="-r";
 
 	if (snprintf(arqin,sizeof(arqin),"%s/%s.utmp",tmp,uinfo->filename)>=sizeof(arqin)) {
-		debuga(_("File name too long: %s/%s.utmp\n"),tmp,uinfo->filename);
+		debuga(_("Path too long: "));
+		debuga_more("%s/%s.utmp\n",tmp,uinfo->filename);
 		exit(EXIT_FAILURE);
 	}
 	if (snprintf(arqou,sizeof(arqou),"%s/htmlrel.txt",tmp)>=sizeof(arqou)) {
-		debuga(_("File name too long: %s/htmlrel.txt\n"),tmp);
+		debuga(_("Path too long: "));
+		debuga_more("%s/htmlrel.txt\n",tmp);
 		exit(EXIT_FAILURE);
 	}
 
 	if(debug) {
-		debuga(_("Sorting file: %s\n"),arqin);
+		debuga(_("Sorting file \"%s\"\n"),arqin);
 	}
 
 	if (snprintf(csort,sizeof(csort),"sort -n -T \"%s\" -t \"\t\" %s -k %s -k %s -k %s -o \"%s\" \"%s\"",tmp,order,field1,field2,field3,arqou,arqin)>=sizeof(csort)) {
-		debuga(_("Sort command too long when sorting file \"%s\" to \"%s\"\n"),arqin,arqou);
+		debuga(_("Command too long: "));
+		debuga_more("sort -n -T \"%s\" -t \"\t\" %s -k %s -k %s -k %s -o \"%s\" \"%s\"",tmp,order,field1,field2,field3,arqou,arqin);
 		exit(EXIT_FAILURE);
 	}
 	cstatus=system(csort);
@@ -122,7 +125,10 @@ void sort_users_log(const char *tmp, int debug,struct userinfostruct *uinfo)
 	clen=snprintf(csort,sizeof(csort),"sort -T \"%s\" -t \"\t\" -k 4,4 -k 1,1 -k 2,2 -o \"%s/%s.user_log\" \"%s/%s.user_unsort\"",
 			tmp, tmp, user, tmp, user);
 	if (clen>=sizeof(csort)) {
-		debuga(_("user name too long to sort %s\n"),csort);
+		/* TRANSLATORS: The message is followed by the command that is too long. */
+		debuga(_("User name too long to sort with command "));
+		debuga_more("sort -T \"%s\" -t \"\t\" -k 4,4 -k 1,1 -k 2,2 -o \"%s/%s.user_log\" \"%s/%s.user_unsort\"",
+			tmp, tmp, user, tmp, user);
 		exit(EXIT_FAILURE);
 	}
 	cstatus=system(csort);
@@ -132,7 +138,8 @@ void sort_users_log(const char *tmp, int debug,struct userinfostruct *uinfo)
 		exit(EXIT_FAILURE);
 	}
 	if (snprintf(csort,sizeof(csort),"%s/%s.user_unsort",tmp,user)>=sizeof(csort)) {
-		debuga(_("user name too long for %s/%s.user_unsort\n"),tmp,user);
+		debuga(_("User name too long to manufacture file name "));
+		debuga_more("%s/%s.user_unsort\n",tmp,user);
 		exit(EXIT_FAILURE);
 	}
 	if (!KeepTempLog && unlink(csort)) {
