@@ -67,7 +67,8 @@ void splitlog(const char *arq, const char *df, int dfrom, int duntil, int conver
 		// '/' + '-YYYY-mm-dd' + '\0' == 13
 		output_prefix_len=snprintf(output_file,sizeof(output_file)-12,"%s%s",outdir,splitprefix);
 		if (output_prefix_len>=sizeof(output_file)-12) {
-			debuga(_("(splitlog) Output path is too long: %s%s-YYYY-mm-dd\n"),outdir,splitprefix);
+			debugapos("splitlog",_("Path too long: "));
+			debuga_more("%s%s-YYYY-mm-dd\n",outdir,splitprefix);
 			exit(EXIT_FAILURE);
 		}
 		autosplit=1;
@@ -81,12 +82,12 @@ void splitlog(const char *arq, const char *df, int dfrom, int duntil, int conver
 	if (arq[0]=='-' && arq[1]=='\0') {
 		fp_in=stdin;
 	} else if((fp_in=MY_FOPEN(arq,"r"))==NULL) {
-		debuga(_("(splitlog) Cannot open log file %s - %s\n"),arq,strerror(errno));
+		debugapos("splitlog",_("Cannot open file \"%s\": %s\n"),arq,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read the log file %s\n"),arq);
+		debuga(_("Not enough memory to read file \"%s\"\n"),arq);
 		exit(EXIT_FAILURE);
 	}
 	time(&min_tt);
@@ -94,7 +95,7 @@ void splitlog(const char *arq, const char *df, int dfrom, int duntil, int conver
 	while((buf=longline_read(fp_in,line))!=NULL) {
 		getword_start(&gwarea,buf);
 		if (getword(data,sizeof(data),&gwarea,' ')<0) {
-			debuga(_("Invalid date found in file %s\n"),arq);
+			debuga(_("Invalid date in file \"%s\"\n"),arq);
 			exit(EXIT_FAILURE);
 		}
 		tt=atoi(data);
@@ -111,7 +112,7 @@ void splitlog(const char *arq, const char *df, int dfrom, int duntil, int conver
 			prev_month=t->tm_mon;
 			prev_day=t->tm_mday;
 			if (fp_ou && fclose(fp_ou)==EOF) {
-				debuga(_("Failed to close file %s - %s\n"),output_file,strerror(errno));
+				debuga(_("Failed to close file \"%s\": %s\n"),output_file,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 			strftime(output_file+output_prefix_len, sizeof(output_file)-output_prefix_len, "-%Y-%m-%d", t);
@@ -121,7 +122,7 @@ void splitlog(const char *arq, const char *df, int dfrom, int duntil, int conver
 			a second time.
 			*/
 			if ((fp_ou=MY_FOPEN(output_file,(tt>=min_tt && tt<=max_tt) ? "a" : "w"))==NULL) {
-				debuga(_("(splitlog) Cannot open output log file %s - %s\n"),output_file,strerror(errno));
+				debugapos("splitlog",_("Cannot open file \"%s\": %s\n"),output_file,strerror(errno));
 				exit(EXIT_FAILURE);
 			}
 			if (tt<min_tt) min_tt=tt;
@@ -142,11 +143,11 @@ void splitlog(const char *arq, const char *df, int dfrom, int duntil, int conver
 
 	longline_destroy(&line);
 	if (fp_in!=stdin && fclose(fp_in)==EOF) {
-		debuga(_("Failed to close file %s - %s\n"),arq,strerror(errno));
+		debuga(_("Failed to close file \"%s\": %s\n"),arq,strerror(errno));
 	}
 	if (autosplit && fp_ou) {
 		if (fclose(fp_ou)==EOF) {
-			debuga(_("Failed to close file %s - %s\n"),output_file,strerror(errno));
+			debuga(_("Failed to close file \"%s\": %s\n"),output_file,strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 	}
