@@ -580,12 +580,12 @@ void read_hostalias(const char *Filename)
 	if (debug) debuga(_("Reading host alias file \"%s\"\n"),Filename);
 	fi=fopen(Filename,"rt");
 	if (!fi) {
-		debuga(_("Cannot read host name alias file \"%s\" - %s\n"),Filename,strerror(errno));
+		debuga(_("Cannot read host name alias file \"%s\": %s\n"),Filename,strerror(errno));
 		exit(EXIT_FAILURE);
 	}
 	
 	if ((line=longline_create())==NULL) {
-		debuga(_("Not enough memory to read the host name aliases\n"));
+		debuga(_("Not enough memory to read file \"%s\"\n"),Filename);
 		exit(EXIT_FAILURE);
 	}
 
