@@ -89,7 +89,7 @@ void useragent(void)
 			debuga(_("Invalid date in file \"%s\"\n"),UserAgentLog);
 			exit(EXIT_FAILURE);
 		}
-		buildymd(day,month,year,wdate);
+		buildymd(day,month,year,wdate,sizeof(wdate));
 		ndate=atoi(wdate);
 		if (ndate<dfrom) continue;
 		if (ndate>duntil) break;
