@@ -2113,7 +2113,7 @@ int extract_address_mask(const char *buf,const char **text,unsigned char *ipv4,u
 	int pad_len;
 	bool bracket=false;
 	bool port=false;
-	bool port_num=0;
+	int port_num=0;
 
 	// skip leading spaces and tabs
 	while (*buf && (*buf==' ' || *buf=='\t')) buf++;
